Index: /trunk/include/VBox/vmm/hm_svm.h
===================================================================
--- /trunk/include/VBox/vmm/hm_svm.h	(revision 71045)
+++ /trunk/include/VBox/vmm/hm_svm.h	(revision 71046)
@@ -707,4 +707,7 @@
 AssertCompileSize(SVMLBRVIRT, 8);
 
+/** Maximum number of bytes in the Guest-instruction bytes field. */
+#define SVM_CTRL_GUEST_INSTR_BYTES_MAX      15
+
 /**
  * SVM VMCB control area.
@@ -770,6 +773,6 @@
     /** Offset 0xd0 - Number of bytes fetched. */
     uint8_t     cbInstrFetched;
-    /** Offset 0xd1 - Fetched bytes. */
-    uint8_t     abInstr[15];
+    /** Offset 0xd1 - Guest instruction bytes. */
+    uint8_t     abInstr[SVM_CTRL_GUEST_INSTR_BYTES_MAX];
     /** Offset 0xe0 - AVIC APIC_BACKING_PAGE pointer. */
     SVMAVIC     AvicBackingPagePtr;
